// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef DOLPHINVCS_VERSION_H
#define DOLPHINVCS_VERSION_H

#define DOLPHINVCS_VERSION_STRING "26.04.2"
#define DOLPHINVCS_VERSION_MAJOR 26
#define DOLPHINVCS_VERSION_MINOR 4
#define DOLPHINVCS_VERSION_PATCH 2
#define DOLPHINVCS_VERSION ((26<<16)|(4<<8)|(2))

#endif
